@@ -62,22 +62,29 @@ sub set_codepage {
 	return if $doc_nr < 0 or not defined $new_value;
 	my $old_value = get_codepage($doc_nr);
 	my $ep = _ep_ref($doc_nr);
-	if    ($old_value eq '8bit' and $new_value eq 'utf8'){
-		Kephra::Document::Data::update_attributes($doc_nr);
-		$ep->SetText( Encode::decode('utf8', $ep->GetText()) );
-		Kephra::Document::Data::evaluate_attributes($doc_nr);
+	if    ($old_value eq 'ascii' and $new_value eq 'utf8'){
+		#unless (Encode::is_utf8($ep->GetText())) {
+			#Kephra::Document::Data::update_attributes($doc_nr);
+			#eval {
+				#Encode::encode('ascii');
+			#	$ep->SetText( Encode::decode('utf8', $ep->GetText()) );
+			#};
+			#print "$@\n";
+			#Kephra::Document::Data::evaluate_attributes($doc_nr);
+		#}
+		#print Encode::is_utf8($ep->GetText())."\n";
 	}
-	elsif ($old_value eq 'utf8' and $new_value eq '8bit') {
-		Kephra::Document::Data::update_attributes($doc_nr);
-		$ep->SetText( Encode::encode('utf8', $ep->GetText()) );
-		Kephra::Document::Data::evaluate_attributes($doc_nr);
+	elsif ($old_value eq 'utf8' and $new_value eq 'ascii') {
+		#Kephra::Document::Data::update_attributes($doc_nr);
+		#$ep->SetText( Encode::encode('utf8', $ep->GetText()) );
+		#Kephra::Document::Data::evaluate_attributes($doc_nr);
 	}
+	#$ep->SetCodePage( &Wx::wxSTC_CP_UTF8 );
 	_set_attr('codepage', $new_value, $doc_nr);
-	#_ep_ref()->SetCodePage( $value );
 	Kephra::App::StatusBar::codepage_info($new_value);
 }
 sub switch_codepage {
-	set_codepage( get_codepage( _doc_nr() ) eq '8bit' ? 'utf8' : '8bit' );
+	set_codepage( get_codepage( _doc_nr() ) eq 'utf8' ? 'ascii' : 'utf8' );
 }
 #
 # tab size
